@@ -760,7 +760,13 @@ void DiagnosticsView::onDoubleClicked(const QModelIndex &index, bool quickFix)
 
 void DiagnosticsView::onDiagnosticsAdded(const FileDiagnostics &diagnostics)
 {
-    if (m_diagnosticsCount > 12000) {
+    auto view = m_mainWindow->activeView();
+    auto doc = view ? view->document() : nullptr;
+    // We allow diagnostics for the active document always because it might be that diagnostic limit is reached
+    // and the user doesn't know about it and thus won't get any further diagnostics at all while typing
+    const bool diagnosticsAreForActiveDoc = doc ? diagnostics.uri == doc->url() : false;
+
+    if (m_diagnosticsCount > 12000 && !diagnosticsAreForActiveDoc) {
         return;
     }
 
@@ -913,7 +919,8 @@ void DiagnosticsView::clearDiagnosticsForStaleDocs(const QList<QString> &filesTo
                 // If the diagnostics of this file item are from multiple providers
                 // delete the ones from @p provider
                 bulk_remove(&m_model, start, count, i);
-                fileItem->removeItemsForProvider(provider);
+                int removedCount = fileItem->removeItemsForProvider(provider);
+                m_diagnosticsCount -= removedCount;
             } else {
                 if (start == -1) {
                     start = i;
