@@ -7,8 +7,8 @@
 #include "ktexteditor_utils.h"
 #include "diagnostics/diagnosticview.h"
 #include "diffwidget.h"
-#include "katemainwindow.h"
 
+#include <QDir>
 #include <QFontDatabase>
 #include <QIcon>
 #include <QMimeDatabase>
@@ -21,6 +21,7 @@
 #include <KTextEditor/Application>
 #include <KTextEditor/Editor>
 #include <KTextEditor/MainWindow>
+#include <KTextEditor/Plugin>
 #include <KTextEditor/View>
 #include <KXMLGUIFactory>
 
@@ -224,23 +225,18 @@ QVariantMap projectMapForDocument(KTextEditor::Document *doc)
     return projectMap;
 }
 
-KTextEditor::Cursor cursorFromOffset(KTextEditor::Document *doc, int offset)
+QString niceFileNameWithPath(const QUrl &url)
 {
-    if (doc && offset >= 0) {
-        const int lineCount = doc->lines();
-        int line = -1;
-        int o = 0;
-        for (int i = 0; i < lineCount; ++i) {
-            int len = doc->lineLength(i);
-            if (o + len >= offset) {
-                line = i;
-                break;
-            }
-            o += len + 1; // + 1 for \n
+    // we want some filename @ folder output to have chance to keep important stuff even on elide
+    if (url.isLocalFile()) {
+        // perhaps shorten the path
+        const QString homePath = QDir::homePath();
+        QString path = url.toString(QUrl::RemoveFilename | QUrl::PreferLocalFile | QUrl::StripTrailingSlash);
+        if (path.startsWith(homePath)) {
+            path = QLatin1String("~") + path.right(path.length() - homePath.length());
         }
-        int col = offset - o;
-        return KTextEditor::Cursor(line, col);
+        return url.fileName() + QStringLiteral(" @ ") + path;
     }
-    return KTextEditor::Cursor::invalid();
+    return url.toDisplayString();
 }
 }
